# -----------------------------------------------------------------------------
# Источники разрешений

PERM_SOURCE__ROLE = 1
PERM_SOURCE__NESTED_ROLE = 2
PERM_SOURCE__DEPENDENCIES = 3


PERM_SOURCES = {
    PERM_SOURCE__ROLE: 'Редактируемая роль',
    PERM_SOURCE__NESTED_ROLE: 'Вложенные роли',
    PERM_SOURCE__DEPENDENCIES: 'Зависимые разрешения',
}
# -----------------------------------------------------------------------------
